
************************
*** IMF capital data ***
************************

* https://www.imf.org/external/np/fad/publicinvestment/pdf/csupdate_jan17.pdf
* http://www.imf.org/external/np/fad/publicinvestment/data/data122216.xlsx

import excel using "Data/Input/Productivity Data/capital_IMF.xlsx", sheet("Data") first clear
keep isocode country year kgov_rppp kpriv_rppp kppp_rppp GDP_rppp
rename isocode iso
rename country Country
rename kgov_rppp K_IMF_gov
rename kpriv_rppp K_IMF_prv
rename kppp_rppp K_IMF_ppp
rename GDP_rppp GDP_IMF

destring K_IMF_gov K_IMF_prv K_IMF_ppp GDP, replace

replace K_IMF_gov = 0 if mi(K_IMF_gov)
replace K_IMF_prv = 0 if mi(K_IMF_prv)
replace K_IMF_ppp = 0 if mi(K_IMF_ppp)

gen K_IMF_tot = K_IMF_gov + K_IMF_prv + K_IMF_ppp

lab var GDP_IMF "GDP in billions of constant 2011 international $"
lab var K_IMF_gov "General govt capital stock in bil. of constant 2011 international $"
lab var K_IMF_prv "Private capital stock in bil. of constant 2011 international $"
lab var K_IMF_ppp "Public-Private Partner capital stock in bil. of constant 2011 international $"
lab var K_IMF_tot "Total capital stock in bil. of constant 2011 international $"

replace K_IMF_gov = K_IMF_gov*1000
replace K_IMF_prv = K_IMF_prv*1000
replace K_IMF_ppp = K_IMF_ppp*1000
replace K_IMF_tot = K_IMF_tot*1000
replace GDP_IMF = GDP_IMF*1000

tempfile K_IMF
save `K_IMF'

*****************************
*** Penn World Table data ***
*****************************

* http://www.rug.nl/ggdc/productivity/pwt/
* http://www.rug.nl/ggdc/docs/pwt90.dta

use "Data/Input/Productivity Data/pwt90.dta", clear
keep countrycode country year rgdpna pop emp avh rconna rkna rtfpna labsh
rename countrycode iso
keep if year<=2013
keep if inlist(iso,"AUS","BEL","CAN","CHE","DEU","DNK","ESP","FIN","FRA") | inlist(iso,"GBR","ITA","JPN","NLD","NOR","PRT","SWE","USA")

gen labinc = rgdpna*labsh
lab var labinc "Labour compensation at constant 2011 national prices (in mil.2011US$)"

replace emp = emp*1000000
gen N = emp*avh
lab var N "Total annual hours worked by persons engaged"

gen W = labinc/N
lab var W "Labour compensation per hour"

merge 1:1 iso year using `K_IMF', keep(1 3) nogen

*****************************************
*** calculate utilization-adjustments ***
*****************************************

* set variables
* output
local Y rgdpna
* labor income
local LY labinc
* labor share of income
local LS labsh
* capital stock
local K K_IMF_prv
* number of employed
local NumEmp emp
* consumption
local C rconna
* average annual hours
local n	avh
* total hours N
local N	N
* labor income per hour
local W W
* GDP to capital stock ratio
local YK YK
* capital stock to GDP ratio
local KY KY

* ratios
gen YK = `Y'/`K'
gen KY = `K'/`Y'
lab var YK "GDP to capital stock ratio"
lab var KY "Capital stock to GDP ratio"

* steady state ratios
egen labsh_ss = mean(`LS'), by(iso)
egen YK_ss = mean(YK), by(iso)
egen KY_ss = mean(KY), by(iso)

* constants
gen delta = 0.1
gen r = 0.04
gen alpha = 1 - ((`KY'_ss)*(r + delta))
gen psi = (alpha/`LS'_ss) - 1

** utilization of capital and labor
gen u = ((`Y'/`K')/(`YK'_ss))^(delta/(delta+r))
gen e = (alpha*(`Y'/`C'))^(1/(1+psi))

egen ccode = group(iso)
tab iso, gen(ccode)
sort ccode year
xtset ccode year
order iso country year ccode*

* non-utilization adjusted TFP
gen x1 = (`K')^(1-alpha)
gen x2 = (N)^(alpha)
gen A = `Y'/(x1*x2)
gen lA = log(A)
gen dlA = d.lA
drop x1 x2

lab var A "TFP"
lab var lA "log of TFP"
lab var dlA "change in log of TFP"

* utilization adjusted TFP
gen x1 = (u*`K')^(1-alpha)
gen x2 = (e*N)^(alpha)
gen A_util = `Y'/(x1*x2)
gen lA_util = log(A_util)
gen dlA_util = d.lA_util
drop x1 x2

lab var A_util "TFP utilization-adjusted"
lab var lA_util "log of TFP utilization-adjusted"
lab var dlA_util "change in log of TFP utilization-adjusted"

gen dlutil = dlA - dlA_util

keep iso year ccode* `Y' `LY' `LS'* `K' `NumEmp' `C' `n' `N' `W' `YK'* `KY'* delta r alpha psi u e *A *A_util dlutil

gen lN = log(N)
gen dlN = d.lN
gen dlN2 = dlN*dlN

levelsof iso, local(isos)
gen dlN_coeff = .

foreach iso of local isos {
	reg dlutil dlN if iso=="`iso'", noconstant
	replace dlN_coeff = _b[dlN] if iso=="`iso'"
}

drop ccode*

save "Data/Input/Productivity Data/util_adj_TFP.dta", replace
