
*********************************************************************************
**** Historical Patterns of Inequality and Productivity around Financial Crises
**** by Pascal Paul, December 2021
**** This File: Constructs Main Datasets
*********************************************************************************

set more off

global root "C:\Users\l1pxp07\Desktop\December 2021"
cd "$root"

*** prepare productivity data
do "Data/Programs/process_productivity_data.do"

*** prepare inequality data
do "Data/Programs/process_inequality_data.do"

*** prepare alternative crises dates data
do "Data/Programs/process_crises_dates_data.do"

*** prepare wealth data
do "Data/Programs/process_wealth_data.do"

*** load in macrofinance data
cd "$root/Data/Input/Macrofinance Data"

local filename "JSTdatasetR2"  // data through 2013
local panelvars year iso ifs country pop
local macrovars rgdpmad rgdppc rconpc gdp iy ca debtgdp
local pricevars cpi stocks hpnom
local creditvars tloans tmort thh tbus
local ratevars stir ltrate
use `panelvars' `macrovars' `pricevars' `creditvars' `ratevars' crisisJST using `filename'.dta, clear
local year "2013"

drop if year>2013

cd "$root"

*** merge in variables from other datasets
merge 1:1 iso year using "Data/Input/Crises Dates Data/ReinhartRogoff_crisis_dates.dta", nogen keep(1 3)
merge 1:1 iso year using "Data/Input/Crises Dates Data/LaevenValencia_crisis_dates.dta", nogen keep(1 3)
merge 1:1 iso year using "Data/Input/Crises Dates Data/Bordo_crisis_dates.dta", nogen keep(1 3)
merge 1:1 iso year using "Data/Input/Crises Dates Data/RomerRomer_fin_distress.dta", nogen keep(1 3)
replace crisisLV = 0 if crisisLV!=1 & inrange(year,1970,2011)
merge 1:1 iso year using "Data/Input/Productivity Data/BCL_tfp_lp_ki_gdp_data.dta", nogen
merge 1:1 iso year using "Data/Input/Productivity Data/util_adj_TFP.dta", nogen
merge 1:1 iso year using "Data/Input/Productivity Data/fernald.dta", nogen keep(1 3)
merge 1:1 iso year using "Data/Input/Inequality Data/inequality.dta", nogen
merge 1:1 iso year using "Data/Input/Wealth Data/wealth_data.dta", nogen

*** make ccodes, sort, tsset
egen ccode = group(iso)
tab iso, gen(ccode)
sort ccode year
xtset ccode year

*** Population
gen lpop = log(pop)

*** CPI
gen lpc 	= log(cpi)
gen dlpc 	= d.lpc

*** House prices
gen hpr 	= hpnom/(cpi/100)
gen lhpr 	= log(hpr)

*** Interest rates
gen rstir 	= stir-dlpc
drop dlpc

*** Stocks
gen rstocks  = stocks/(cpi/100)
gen lrstocks = log(rstocks)

*** GDP 
*gen rgdp	= rgdpmad
gen rgdp	= rgdppc
gen lrgdp 	= log(rgdp)
gen rGDP 	= rgdp*(pop*1000)
gen lrGDP 	= log(rGDP)

*** Global GDP
egen Gl_rGDP = total(rGDP), by(year)
gen lGl_rGDP = log(Gl_rGDP)

*** Investment
gen riy 	= iy*rgdp
gen lriy 	= log(riy)

*** Loans
* total loans
gen loansr 	= tloans/(cpi/100)
gen lloans 	= log(tloans)
gen lloansr = lloans-lpc
gen lrprv  	= lloans - lpc - lpop

* firm loans = tbus
gen firmloansr 	= tbus/(cpi/100)
gen lfirmloansr = log(firmloansr)

* HH loans = thh
gen hhloansr 	= thh/(cpi/100)
gen lhhloansr 	= log(hhloansr)

* mortgage loans = tm
gen mortloans 	= tm
gen mortloansr 	= mortloans/(cpi/100)
gen lmortloansr = log(mortloansr)

* non-mortgage loans = tloans - tm
gen nmortloans 		= tloans - mortloans
gen nmortloansr 	= nmortloans/(cpi/100)
gen lnmortloansr 	= log(nmortloansr)

*** Productivity
* labor productivity
gen llp 	= log(lp)

* total factor productivity
gen ltfp 	= log(tfp)
gen dltfp 	= d.ltfp

* utlization-adjusted TFP using Fernald estimates
replace pop = pop*1000
gen GDP_bcl = gdp_bcl * pop

gen total_hours = (lp/GDP_bcl)^(-1)
gen lhours 		= log(total_hours)
gen dlhours 	= d.lhours

gen dutil_pred_Fernald = dlhours*$dhours_beta
gen dltfp_util_Fernald = dltfp - (dutil_pred_Fernald)

* utilization-adjustment for TFP using IMF and PWT data (based on Imbs method)
sort iso year
tsset ccode year, yearly

egen dlN_coef 		= max(dlN_coeff), by(iso)
*egen dlN_cons = max(dlN_const), by(iso)

gen dlutil_pred 	= dlN_coef*dlhours
gen dltfp_util 		= dltfp - dlutil_pred

gen ltfp_util 		= 1 if !mi(F.dltfp_util) & mi(L.dltfp_util) & mi(dltfp_util)
replace ltfp_util 	= L.ltfp_util + dltfp_util if !mi(L.ltfp_util)

* current account-to-GDP
gen cay	= ca/gdp

* loans-to-GDP
gen loansgdp = tloans/gdp

sort ccode year
xtset ccode year 

cd "$root/Data/Input/Recession Dates Data/"

* Hard-coded program that sets dates for variables recessions - normal, financial
qui include peak_dummies_June2017.do

sort ccode year
xtset ccode year

foreach var in lrprv lrgdp lpc lriy {
	gen d`var' = 100*d.`var'
}

*** drop wars

if $exclude_wars == 1 {

	gen ww1 = 1 if year>=1914 & year<=1919
	gen ww2 = 1 if year>=1939 & year<=1947
	replace ww1 = 0 if ww1~=1
	replace ww2 = 0 if ww2~=1
	drop if ww1==1 | ww2==1

}

sort ccode year
xtset ccode year

*** label main vars

lab var income_top001 		"Income Share Top 0.01%"
lab var income_top01  		"Income Share Top 0.1%"
lab var income_top1   		"Income Share Top 1%"
lab var income_top10  		"Income Share Top 10%"
lab var income_top001_fisc  "Income Share Top 0.01 (incl. Cap Gains)%"
lab var income_top01_fisc   "Income Share Top 0.1% (incl. Cap Gains)"
lab var income_top1_fisc    "Income Share Top 1% (incl. Cap Gains)"
lab var income_top10_fisc   "Income Share Top 10% (incl. Cap Gains)"

lab var wealth_top1     	"Wealth Share Top 1%"
lab var wealth_top10    	"Wealth Share Top 10%"
lab var wealth_income   	"Wealth-to-income ratio"

lab var ltfp 				"TFP (log)"
lab var ltfp_util   		"TFP util.-adj. (log)"
lab var llp 				"Labor Productivity (log)"

lab var lloansr 			"real total Loans (log)"
lab var lrgdp 				"real GDP (log)"
lab var lrstocks 			"real Stock Prices (log)"
lab var lhpr 				"real House Prices (log)"
lab var cay 				"Current Account-to-GDP"
lab var loansgdp 			"Loans-to-GDP"
lab var stir 				"Short-term Nominal Interest Rate"
lab var rstir 				"Short-term Real Interest Rate"
lab var ltrate 				"Long-term Nominal Interest Rate"
lab var iy 					"Investment-to-GDP"
lab var lfirmloansr 		"real Firm Loans (log)"
lab var lhhloansr 			"real Household Loans (log)"
lab var lmortloansr 		"real Mortgages (log)"
lab var lnmortloansr 		"real Nonmortgages (log)"
lab var debtgdp 			"Government-debt-to-GDP"
lab var lGl_rGDP  			"Global real GDP (log)"
lab var lpc 				"Price Index (log)"
lab var lrprv 				"Real per capita Private Loans (log)"
lab var lriy				"Real per capita Investment (log)"

lab var crisisJST 			"Financial Crises Indicator"
lab var crisisReinRog 		"Financial Crises Indicator (Reinhard & Rogoff)"
lab var crisisLV  			"Financial Crises Indicator (Laeven & Valencia)"
lab var crisisBordo  		"Financial Crises Indicator (Bordo et al.)"
lab var crisisFinDistRR 	"Financial Crises Indicator (Romer & Romer)"
lab var crisisFinDistRR7up1 "FCI (Romer & Romer), start for crisis above >=7"

lab var pk_norm 			"Nonfinancial Recession Indicator"
lab var pk_fin 				"Financial Recession Indicator"

lab var dutil 				"Utilization adjustment Fernald"
lab var dlutil 				"Utilization adjustment Imbs-method"
lab var dlutil_pred 		"Utilization adjustment Imbs-method, extrapolated backwards"

************************
*** Description Data ***
************************

preserve

	keep 						year ccode iso ///
	/*Inequality Data*/ 		income* ///
	/*Productivity Data*/ 		ltfp ltfp_util llp ///
	/*Macrofinance Data*/ 		lloansr ///
	/*Crises Dates*/ 			crisisJST ///
	/*Recession Dates*/ 		pk_norm pk_fin ///
	/*Fernald Data*/ 			dtfp dtfp_util dLP ///
	/*Utilization adjusments*/ 	dutil dlutil dlutil_pred

	save "$root/Data/Output/Dataset_description.dta", replace

restore

***********************
*** Prediction Data ***
***********************

preserve

	keep 					year ccode iso ccode* ///
	/*Inequality Data*/ 	income* ///
	/*Wealth Data*/ 		wealth* ///
	/*Productivity Data*/ 	ltfp ltfp_util llp ///
	/*Macrofinance Data*/ 	lloansr lrgdp lrstocks lhpr cay loansgdp stir rstir ltrate iy lfirmloansr lhhloansr lmortloansr lnmortloansr debtgdp lGl_rGDP lpc ///
	/*Crises Dates*/ 		crisisJST crisisReinRog crisisLV crisisBordo crisisFinDistRR crisisFinDistRR7up1 ///
	/*Recession Dates*/ 	pk_norm pk_fin ///

	save "$root/Data/Output/Dataset_prediction.dta", replace
	
restore

****************************
*** Trend vs. Cycle Data ***
****************************

preserve

	keep 					year ccode iso ccode* ///
	/*Inequality Data*/ 	income* ///
	/*Productivity Data*/ 	ltfp_util llp ///
	/*Macrofinance Data*/ 	lloansr lrstocks lhpr cay loansgdp ///
	/*Crises Dates*/ 		crisisJST  ///

	save "$root/Data/Output/Dataset_trend_cycle.dta", replace
	
restore

**********************
*** Aftermath Data  **
**********************

preserve

	keep 						year ccode iso ccode* ///
	/*Inequality Data*/ 		income* ///
	/*Wealth Data*/ 			wealth* ///
	/*Productivity Data*/ 		ltfp ltfp_util llp ///
	/*Macrofinance Data*/ 		lloansr lrgdp lrstocks lhpr cay loansgdp stir rstir ltrate iy lfirmloansr lhhloansr lmortloansr lnmortloansr debtgdp lGl_rGDP lpc lrprv lriy ///
	/*First-differenced Data*/ 	dlrprv dlrgdp dlpc dlriy ///
	/*Crises Dates*/ 			crisisJST crisisReinRog crisisLV crisisBordo crisisFinDistRR ///
	/*Recession Dates*/ 		pk_norm pk_fin ///

	save "$root/Data/Output/Dataset_aftermath.dta", replace
	
restore
